<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use \Zeedhi\Framework\Util\Functions;

class RelCustoComposicaoProduto extends CrudWithParameterBag {
    
    protected $relCustoComposicaoProdutoService;
    protected $tabelaPrecoService;
    protected $dataSourceNameArray = array (
        'filterLoja' => 'vnd07800_relCustoComposicaoProduto_loja',
        'filterProdutoSegfam' => 'vnd07800_relCustoComposicaoProduto_produto_segfam',
        'filterProdutoFamilia' => 'vnd07800_relCustoComposicaoProduto_produto_familia',
        'filterProdutoSegmento' => 'vnd07800_relCustoComposicaoProduto_produto_segmento',
        'filterProdutoNormal' => 'vnd07800_relCustoComposicaoProduto_produto_normal'
    );
    
    protected $parameterBagColumnsArray = array (
        'filterLoja' => array('CDFILIAL', 'NRORG'),
        'filterProdutoSegfam' => array('CDFILIAL', 'CDSEGMER', 'CDGRUPPROD', 'NRORG'),
        'filterProdutoFamilia' => array('CDFILIAL', 'CDGRUPPROD', 'NRORG'),
        'filterProdutoSegmento' => array('CDFILIAL', 'CDSEGMER', 'NRORG'),
        'filterProdutoNormal' => array('CDFILIAL', 'CDNVPRODUTO', 'NRORG')
    );
    protected $util;
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Services\RelCustoComposicaoProduto $relCustoComposicaoProdutoService, Services\TabelaPreco $tabelaPrecoService, Utilities\Util $util){
        $this->relCustoComposicaoProdutoService = $relCustoComposicaoProdutoService;
        $this->tabelaPrecoService = $tabelaPrecoService;
        parent::__construct($dataSourceManager, $parameterBag);
        $this->util = $util;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $produtosPai = [];
        $conditions = $this->util->getParamsAsArray($request);
        
        if(isset($conditions['INTERVALISTA']) && !empty($conditions['INTERVALISTA']) &&
           isset($conditions['CDFILIAL'])     && !empty($conditions['CDFILIAL'])     &&
           isset($conditions['CDLOJA'])       && !empty($conditions['CDLOJA'])       &&
           isset($conditions['CDCOMPOSICAO']) && !empty($conditions['CDCOMPOSICAO']) &&
           isset($conditions['CDTIPOCUSTO'])  && !empty($conditions['CDTIPOCUSTO'])) {
            if ($conditions['INTERVALISTA'] == 'I'){
                $conditions['CDPRODINI'] = str_replace('%', '', $conditions['CDPRODINI']);
                if (empty($conditions['CDPRODFIN'])){
                    $conditions['CDPRODFIN'] = $conditions['CDPRODINI'];
                }else{
                    $conditions['CDPRODFIN'] = str_replace('%', '', $conditions['CDPRODFIN']);
                }
                $conditions['CDPRODUTO'] = null;
                $conditions['PRODNIV'] = null;
            }elseif ($conditions['INTERVALISTA'] == 'D') {
               $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
               $conditions['CDPRODUTO'] = null;
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
            }
            else{
               $conditions['CDPRODUTO'] = implode('_', $conditions['CDPRODUTO']);
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
               $conditions['PRODNIV'] = null;
            }
            
            $NRORG           = $conditions['NRORG'];
            $CDFILIALLOGADA  = $conditions['CDFILIALLOGADA'];
            $CDCOMPOSICAO    = $conditions['CDCOMPOSICAO'];
            $CDFILIAL        = $conditions['CDFILIAL'];
            $CDLOJA          = $conditions['CDLOJA'];
            $CDPRODINI       = $conditions['CDPRODINI'];
            $CDPRODFIN       = $conditions['CDPRODFIN'];
            $NMTIPOCUSTO     = $conditions['CDTIPOCUSTO'];
            $CDPRODLIST      = $conditions['CDPRODUTO'];
            $PRODNIV         = $conditions['PRODNIV'];
            //$FILIAL = $CDCOMPOSICAO == 'P' ?  $CDFILIAL :  $CDFILIALLOGADA;
            $FILIAL = $CDFILIAL;
            $tabPrec = $this->relCustoComposicaoProdutoService->getTabPrec($NRORG, $CDFILIAL, $CDLOJA);
            
            
            if(!empty($tabPrec['TABLOJA'])){
                $CDTABPREC = $tabPrec['TABLOJA'];
                $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            } else if(!empty($tabPrec['TABPADRAO'])) {
               $CDTABPREC = $tabPrec['TABPADRAO'];
               $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            }else if(!empty($tabPrec['TABGERAL'])){
               $CDTABPREC = $tabPrec['TABGERAL'];
               $produtosPai= $this->relCustoComposicaoProdutoService->getProdTabGeral($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            }else{
               $produtosPai = [];
               $CDTABPREC = null;
            }
            
            
            $params = array( 
                'CDTABEPREC'   => $CDTABPREC,
                'CDFILIAL'     => $FILIAL,
                'NMTIPOCUSTO'  => $NMTIPOCUSTO,
                'CDLOJA'       => $CDLOJA,
                'CDCOMPOSICAO' => $CDCOMPOSICAO
            );
            
            if($produtosPai){
               for( $i = 0; count($produtosPai) > $i; $i++) {
                   $TXROTFAB = $this->relCustoComposicaoProdutoService->getInstr($FILIAL, $produtosPai[$i]['CDPRODUTO'], $NRORG, $CDCOMPOSICAO);
                   $CUSTO = $this->relCustoComposicaoProdutoService->procedureCustoCompProd($params, $produtosPai[$i]);
                   $produtosPai[$i]['CUSTO'] = $CUSTO;
                   $produtosPai[$i]['QTSUBPRODROT'] = 1;
               }
            }
        }
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd07800_relCustoComposicaoProduto', $produtosPai));
    }
    
    public function findIndexada(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->util->getParamsAsArray($request);
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])) {
            if ($conditions['INTERVALISTA'] == 'I'){
                $conditions['CDPRODINI'] = str_replace('%', '', $conditions['CDPRODINI']);
                if (empty($conditions['CDPRODFIN'])){
                    $conditions['CDPRODFIN'] = $conditions['CDPRODINI'];
                }else{
                    $conditions['CDPRODFIN'] = str_replace('%', '', $conditions['CDPRODFIN']);
                }
                $conditions['CDPRODUTO'] = null;
                $conditions['PRODNIV'] = null;
            }elseif ($conditions['INTERVALISTA'] == 'D') {
               $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
               $conditions['CDPRODUTO'] = null;
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
            }
            else{
               $conditions['CDPRODUTO'] = implode('_', $conditions['CDPRODUTO']);
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
               $conditions['PRODNIV'] = null;
            }
            $NRORG           = $conditions['NRORG'];
            $CDFILIALLOGADA  = $conditions['CDFILIALLOGADA'];
            $CDCOMPOSICAO    = $conditions['CDCOMPOSICAO'];
            $CDFILIAL        = $conditions['CDFILIAL'];
            $CDLOJA          = $conditions['CDLOJA'];
            $CDPRODLIST      = $conditions['CDPRODUTO'];
            $PRODNIV         = $conditions['PRODNIV'];
            $CDPRODINI       = str_replace('%', '', $conditions['CDPRODINI']);
            $CDPRODFIN       = str_replace('%', '', $conditions['CDPRODFIN']);
            $NMTIPOCUSTO     = str_replace('%', '', $conditions['CDTIPOCUSTO']);
            $RETORNO = []; 
            //$FILIAL = $CDCOMPOSICAO == 'P' ?  $CDFILIAL :  $CDFILIALLOGADA;
            $FILIAL = $CDFILIAL;
            $dataAtual = new \DateTime();
            $dataAtual = $dataAtual->format('d/m/Y');
            
           $tabPrec = $this->relCustoComposicaoProdutoService->getTabPrec($NRORG, $CDFILIAL, $CDLOJA);
          
           if(!empty($tabPrec['TABLOJA'])){
                $CDTABPREC = $tabPrec['TABLOJA'];
                $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
           } else if(!empty($tabPrec['TABPADRAO'])) {
               $CDTABPREC = $tabPrec['TABPADRAO'];
               $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
           }else if(!empty($tabPrec['TABGERAL'])){
               $CDTABPREC = $tabPrec['TABGERAL'];
               $produtosPai= $this->relCustoComposicaoProdutoService->getProdTabGeral($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
           }else{
               $produtosPai = [];
               $CDTABPREC = null;
           }
            $params = array( 
            	'CDTABEPREC'  =>  $CDTABPREC,
            	'CDFILIAL'    =>  $FILIAL,
            	'NMTIPOCUSTO' =>  $NMTIPOCUSTO ,
            	'CDLOJA'      =>  $CDLOJA
    		);
            if($produtosPai){
               for( $i = 0; count($produtosPai) > $i; $i++) {
                   $TXROTFAB        = $this->relCustoComposicaoProdutoService->getInstr($FILIAL, $produtosPai[$i]['CDPRODUTO'], $NRORG, $CDCOMPOSICAO);
                   $ARRAYCOMPOSICAO = $this->relCustoComposicaoProdutoService->getComposicaoProduto($produtosPai[$i]['CDPRODUTO'], $NRORG, [], $CDCOMPOSICAO, $CDFILIAL, $produtosPai[$i]['CDPRODUTO']);
                   $PRECOITEM       = $this->relCustoComposicaoProdutoService->getPrecoItem($NRORG, $CDFILIAL, $produtosPai[$i]['CDPRODUTO'], $CDTABPREC, $dataAtual);
                   $CUMUPISCOFIL    = $this->relCustoComposicaoProdutoService->getCumuPisCoFil($NRORG, $CDFILIAL);
                   $ALIQPISCONFINS  = $this->relCustoComposicaoProdutoService->getAliqPisConfins($NRORG, $CDFILIAL, $produtosPai[$i]['CDPRODUTO']);
                   
                   if(is_array($ALIQPISCONFINS)) {
                        $ICMS = $ALIQPISCONFINS['VRPEALIMPFIS'];
                   } else {
                        $ICMS = 0;
                   }
                   
                   if($PRECOITEM == false){
                      $PRECOITEM['VRPRECITEM'] = 0;
                   }
                    if ($CUMUPISCOFIL['IDCUMUPISCOFIL'] == 'N' ) {
                      $Pis    = 0.65;
                      $Cofins = 3;
                    } else {
                      $Pis    = 1.65;
                      $Cofins = 7.60;
                    }  
                    if ($CUMUPISCOFIL['IDCUMUPISCOFIL'] == 'S') {
                        $VrPis    = $PRECOITEM['VRPRECITEM'] * ($Pis/100);
                        $VrCofins = $PRECOITEM['VRPRECITEM'] * ($Cofins/100);
                    } else {
                        $VrPis    = 0;
                        $VrCofins = 0;
                    }
                    $VrICMS = $PRECOITEM['VRPRECITEM'] * ($ICMS/100);
                    $VrImposto = $VrPis + $VrCofins + $VrICMS;
                    for( $j = 0; count($ARRAYCOMPOSICAO[0]) > $j; $j++) {
                        $ARRAYCOMPOSICAO[0][$j]['CUSTO'] = $this->relCustoComposicaoProdutoService->procedureCustoCompProd($params, $ARRAYCOMPOSICAO[0][$j]);
                        $ARRAYCOMPOSICAO[0][$j]['TXINSTR'] = $TXROTFAB;
                        $ARRAYCOMPOSICAO[0][$j]['CUSTO'] = $ARRAYCOMPOSICAO[0][$j]['CUSTO'] * $ARRAYCOMPOSICAO[0][$j]['QTSUBPRODROT'];
                        array_push($RETORNO, $ARRAYCOMPOSICAO[0][$j]);
                    } 
               }
           }
           $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd07800_relCustoComposicaoProdutoIndexada', $RETORNO));
        }
        return $result;
    }
    
    public function findNivelUnico(DTO\Request\Filter $request, DTO\Response $response) {
       $conditions = $this->util->getParamsAsArray($request);
       $RETORNO = [];
       if(isset ($conditions['INTERVALISTA'])){
        $conditions['TCDPRODUTO'] = 'T';
       
        if(!Functions::arrayKeyExists('CDARVPRODI', $conditions)) {
            
            $conditions['CDARVPRODI'] = null;
        }

        if(!Functions::arrayKeyExists('CDARVPRODF', $conditions)) {
            $conditions['CDARVPRODF'] = null;
        }
        
        if(Functions::arrayKeyExists('DTENTRVENDA', $conditions)) {
            $conditions['DTVENDAINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTVENDAFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        
         if (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'I'){
           if (empty($conditions['CDARVPRODF'])){
                $conditions['CDARVPRODF'] = $conditions['CDARVPRODI'];
          }
          $conditions['CDARVPRODI'] = str_replace("%", "",$conditions['CDARVPRODI']);
          $conditions['CDARVPRODF'] = str_replace("%", "",$conditions['CDARVPRODF']);
          $conditions["CDARVPRODF"]=str_pad($conditions["CDARVPRODF"], 15, 'z');
          $conditions['TCDPRODUTO'] = null;
          $conditions['CDPRODLIST'] = null;
          $conditions['PRODNIV'] = null;
            
           
        }elseif (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'D') {
           $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
           $conditions['TCDPRODUTO'] = null;
           $conditions['CDPRODLIST'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
         
        }
        elseif (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'L'){
           $conditions['CDPRODLIST'] = implode('_', $conditions['CDPRODUTO']);
           $conditions['TCDPRODUTO'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
           $conditions['PRODNIV'] = null;
          
        } 
        else{
           $conditions['TCDPRODUTO'] = 'T';
           $conditions['CDPRODLIST'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
           $conditions['PRODNIV'] = null;
        
       }
       $NRORG           = $conditions['NRORG'];   
       $CDFILIALLOGADA  = $conditions['CDFILIALLOGADA'];
       $CDCOMPOSICAO    = $conditions['CDCOMPOSICAO'];
       $CDFILIAL        = $conditions['CDFILIAL'];
       $CDLOJA          = $conditions['CDLOJA'];
       $CDPRODLIST     = $conditions['CDPRODLIST'];
       $PRODNIV     = $conditions['PRODNIV'];
       $CDPRODINI       = $conditions['CDARVPRODI'];
       $CDPRODFIN       = $conditions['CDARVPRODF'];
       $NMTIPOCUSTO     = str_replace('%', '', $conditions['CDTIPOCUSTO']);
       //$FILIAL = $CDCOMPOSICAO == 'P' ?  $CDFILIAL :  $CDFILIALLOGADA;
       $FILIAL = $CDFILIAL;
          
       $dataAtual = new \DateTime();
       $dataAtual = $dataAtual->format('d/m/Y');
       
       $tabPrec = $this->relCustoComposicaoProdutoService->getTabPrec($NRORG, $CDFILIAL, $CDLOJA);
       
      
       if(!empty($tabPrec['TABLOJA'])){
            $CDTABPREC = $tabPrec['TABLOJA'];
            $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
       } else if(!empty($tabPrec['TABPADRAO'])) {
           $CDTABPREC = $tabPrec['TABPADRAO'];
           $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
       }else if(!empty($tabPrec['TABGERAL'])){
           $CDTABPREC = $tabPrec['TABGERAL'];
           $produtosPai= $this->relCustoComposicaoProdutoService->getProdTabGeral($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
       }else{
           $produtosPai = [];
           $CDTABPREC = null;
       }
      
       $params = array( 
			'CDTABEPREC'  =>  $CDTABPREC,
			'CDFILIAL'    =>  $FILIAL,
			'NMTIPOCUSTO' =>  $NMTIPOCUSTO ,
			'CDLOJA'      =>  $CDLOJA
		);
		
        if($produtosPai){
           for( $i = 0; count($produtosPai) > $i; $i++) {
               $TXROTFAB        = $this->relCustoComposicaoProdutoService->getInstr($FILIAL, $produtosPai[$i]['CDPRODUTO'], $NRORG, $CDCOMPOSICAO);
               $ARRAYCOMPOSICAO = $this->relCustoComposicaoProdutoService->getComposicaoTodosProdutos($produtosPai[$i]['CDPRODUTO'], $NRORG, [], $CDCOMPOSICAO, $CDFILIAL, $produtosPai[$i]['CDPRODUTO']);
               $LABELFILIAL     = $this->relCustoComposicaoProdutoService->getLabelFilial($FILIAL, $NRORG, $CDLOJA);
               $PRECOITEM       = $this->relCustoComposicaoProdutoService->getPrecoItem($NRORG, $CDFILIAL, $produtosPai[$i]['CDPRODUTO'], $CDTABPREC, $dataAtual);

                
                for( $j = 0; count($ARRAYCOMPOSICAO[0]) > $j; $j++) {
                    $ARRAYCOMPOSICAO[0][$j]['CUSTO'] = $this->relCustoComposicaoProdutoService->procedureCustoCompProd($params, $ARRAYCOMPOSICAO[0][$j]);
                    $ARRAYCOMPOSICAO[0][$j]['CUSTOTOTAL'] = $ARRAYCOMPOSICAO[0][$j]['CUSTO'] * $ARRAYCOMPOSICAO[0][$j]['QTSUBPRODROT'];
                    $ARRAYCOMPOSICAO[0][$j]['TXINSTR'] = $TXROTFAB;
                    array_push($RETORNO, $ARRAYCOMPOSICAO[0][$j]);
                } 
           }
       }

       } 
       $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd07800_relCustoComposicaoProdutoNivelUnico', $RETORNO));
       
    
    }
    
    public function findNivelUnicoProdutoAdicional(DTO\Request\Filter $request, DTO\Response $response) {
        $RETORNO = [];
        $conditions = $this->util->getParamsAsArray($request);
       
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])) {   
            if ($conditions['INTERVALISTA'] == 'I'){
                $conditions['CDPRODINI'] = str_replace('%', '', $conditions['CDPRODINI']);
                if (empty($conditions['CDPRODFIN'])){
                    $conditions['CDPRODFIN'] = $conditions['CDPRODINI'];
                }else{
                    $conditions['CDPRODFIN'] = str_replace('%', '', $conditions['CDPRODFIN']);
                }
                $conditions['CDPRODUTO'] = null;
                $conditions['PRODNIV'] = null;
            }elseif ($conditions['INTERVALISTA'] == 'D') {
               $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
               $conditions['CDPRODUTO'] = null;
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
            }
            else{
               $conditions['CDPRODUTO'] = implode('_', $conditions['CDPRODUTO']);
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
               $conditions['PRODNIV'] = null;
            }
               $NRORG           = $conditions['NRORG'];
               $CDFILIALLOGADA  = $conditions['CDFILIALLOGADA'];
               $CDCOMPOSICAO    = 'P';
               $CDFILIAL        = $conditions['CDFILIAL'];
               $CDLOJA          = $conditions['CDLOJA'];
               $CDPRODLIST     = $conditions['CDPRODUTO'];
               $PRODNIV     = $conditions['PRODNIV'];
               $CDPRODINI       = str_replace('%', '', $conditions['CDPRODINI']);
               $CDPRODFIN       = str_replace('%', '', $conditions['CDPRODFIN']);
               $NMTIPOCUSTO     = str_replace('%', '', $conditions['CDTIPOCUSTO']);
               //$FILIAL = $CDCOMPOSICAO == 'P' ?  $CDFILIAL :  $CDFILIALLOGADA;
               $FILIAL = $CDFILIAL;
               $dataAtual = new \DateTime();
               $dataAtual = $dataAtual->format('d/m/Y');
               $tabPrec = $this->relCustoComposicaoProdutoService->getTabPrec($NRORG, $CDFILIAL, $CDLOJA);
               
          
            if(!empty($tabPrec['TABLOJA'])){
                $CDTABPREC = $tabPrec['TABLOJA'];
                $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            } else if(!empty($tabPrec['TABPADRAO'])) {
               $CDTABPREC = $tabPrec['TABPADRAO'];
               $produtosPai = $this->relCustoComposicaoProdutoService->getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            }else if(!empty($tabPrec['TABGERAL'])){
               $CDTABPREC = $tabPrec['TABGERAL'];
               $produtosPai= $this->relCustoComposicaoProdutoService->getProdTabGeral($CDTABPREC, $CDPRODINI, $CDPRODFIN,  $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV);
            }else{
               $produtosPai = [];
               $CDTABPREC = null;
            }
          
            $params = array( 
    			'CDTABEPREC'  =>  $CDTABPREC,
    			'CDFILIAL'    =>  $FILIAL,
    			'NMTIPOCUSTO' =>  $NMTIPOCUSTO ,
    			'CDLOJA'      =>  $CDLOJA
    		);
            if($produtosPai){
                for( $i = 0; count($produtosPai) > $i; $i++) {
                   $TXROTFAB        = $this->relCustoComposicaoProdutoService->getInstr($FILIAL, $produtosPai[$i]['CDPRODUTO'], $NRORG, $CDCOMPOSICAO);
                   $ARRAYCOMPOSICAO = $this->relCustoComposicaoProdutoService->getComposicaoTodosProdutos($produtosPai[$i]['CDPRODUTO'], $NRORG, [], $CDCOMPOSICAO, $CDFILIAL, $produtosPai[$i]['CDPRODUTO']);
                   $PRECOITEM       = $this->relCustoComposicaoProdutoService->getPrecoItem($NRORG, $CDFILIAL, $produtosPai[$i]['CDPRODUTO'], $CDTABPREC, $dataAtual);
                   $PRODUTOADC      = $this->relCustoComposicaoProdutoService->getProdutoAdc($produtosPai[$i]['CDPRODUTO'], $NRORG, $FILIAL, $produtosPai[$i]['CDPRODUTO']);
                   if(!empty($PRODUTOADC)){
                       foreach($PRODUTOADC as $produto){
                        array_push($ARRAYCOMPOSICAO[0], $produto);
                       }
                   }
                    for( $j = 0; count($ARRAYCOMPOSICAO[0]) > $j; $j++) {
                        $ARRAYCOMPOSICAO[0][$j]['CUSTO'] = $this->relCustoComposicaoProdutoService->procedureCustoCompProd($params, $ARRAYCOMPOSICAO[0][$j]);
                        $ARRAYCOMPOSICAO[0][$j]['CUSTOTOTAL'] = $ARRAYCOMPOSICAO[0][$j]['CUSTO'] * $ARRAYCOMPOSICAO[0][$j]['QTSUBPRODROT'];
                        $ARRAYCOMPOSICAO[0][$j]['TXINSTR'] = $TXROTFAB;
                        array_push($RETORNO, $ARRAYCOMPOSICAO[0][$j]);
                    } 
                }
           }
        }
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd07800_relCustoComposicaoProdutoNivelUnicoAdicionais', $RETORNO));
        
    }
    
    public function findLoja(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['filterLoja'];
        $this->parameterBagColumns = $this->parameterBagColumnsArray['filterLoja'];
        parent::find($request, $response);
    }
    
    public function findProduto(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $request->getFilterCriteria()->getConditions();
        $codGrupoProd = $this->relCustoComposicaoProdutoService->getGrupoProd($conditions[3]['value'], $conditions[0]['value']);
        $codGrupoProd = !empty($codGrupoProd) ? $codGrupoProd[0]['CDGRPRODPDV'] : NULL;
        
        $cdSegmer = $conditions[1]['value'];
        if($codGrupoProd !== null) {
           // Utiliza família
            $conditions[] = array('columnName' => 'CDGRUPPROD',
                                  'value' => $codGrupoProd,
                                  'operator' => '=');
            if($cdSegmer !== null) {
              // Utiliza família / segmento
                unset($conditions[2]);
                $this->dataSourceName = $this->dataSourceNameArray['filterProdutoSegfam'];
                $this->parameterBagColumns = $this->parameterBagColumnsArray['filterProdutoSegfam'];
            } else {
              // Utiliza família
                unset($conditions[1]);
                unset($conditions[2]);
                $this->dataSourceName = $this->dataSourceNameArray['filterProdutoFamilia'];
                $this->parameterBagColumns = $this->parameterBagColumnsArray['filterProdutoFamilia'];
            }
        } else {
            if($cdSegmer !== null) {
              // Utiliza segmento
                unset($conditions[2]);
                $this->dataSourceName = $this->dataSourceNameArray['filterProdutoSegmento'];
                $this->parameterBagColumns = $this->parameterBagColumnsArray['filterProdutoSegmento'];
            } else {
              // Não utiliza nada
                unset($conditions[1]);
                $this->dataSourceName = $this->dataSourceNameArray['filterProdutoNormal'];
                $this->parameterBagColumns = $this->parameterBagColumnsArray['filterProdutoNormal'];
            }
        }
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $request->getFilterCriteria()->getDataSourceName(),
                $conditions,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        parent::find($newRequest, $response);
    }
    
    public function findCompLocPadr(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->util->getParamsAsArray($request);
        $data=[];
    if(isset($conditions['CDFILIAL'])){    
        if(isset($conditions['INTERVALISTA'])){
            if ($conditions['INTERVALISTA'] == 'I'){
                $conditions['CDPRODINI'] = str_replace('%', '', $conditions['CDPRODINI']);
                if (empty($conditions['CDPRODFIN'])){
                    $conditions['CDPRODFIN'] = $conditions['CDPRODINI'];
                }else{
                    $conditions['CDPRODFIN'] = str_replace('%', '', $conditions['CDPRODFIN']);
                }
                $conditions['CDPRODUTO'] = null;
                $conditions['PRODNIV'] = null;
            }elseif ($conditions['INTERVALISTA'] == 'D') {
               $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
               $conditions['CDPRODLIST'] = null;
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
               $conditions['TCDPRODUTO'] = 'E';
            }
            else {
               $conditions['CDPRODLIST'] = implode('_', $conditions['CDPRODUTO']);
               $conditions['CDPRODFIN'] = null;
               $conditions['CDPRODINI'] = null;
               $conditions['PRODNIV'] = null;
               $conditions['TCDPRODUTO'] = 'E';
            }
        }
        else{
           $conditions['CDPRODLIST'] = null;
           $conditions['CDPRODFIN'] = null;
           $conditions['CDPRODINI'] = null;
           $conditions['PRODNIV'] = null;
           $conditions['TCDPRODUTO'] = 'T';
        }
        $data = $this->relCustoComposicaoProdutoService->getCompPadrLoc($conditions);
    }
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd55024_relCompLocPadr', $data));
    }
}