<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use \Zeedhi\Framework\Util\Functions;

class RelSaldoAtualporConsumidor extends CrudWithParameterBag {
    protected $dataSourceName = 'vnd09500R_relSaldoAtualporConsumidor';
    protected $parameterBagColumns = array('CDCLIENTE','CDCONSUMIDOR','TCDCONSUMIDOR','CDTIPOCONS','TCDTIPOCONS','CDFAMILISALD','TCDFAMILISALD','DTEXTRATOINI','DTEXTRATOFIN');

    public function __construct($dataSourceManager, $parameterBag, $utilService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $dataSourceName = $this->dataSourceName = 'vnd09500R_relSaldoAtualporConsumidor';

        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParamsSaldo($conditions);
 
        foreach($conditions as $key => $value) {
            $dataSourceFilter[] = $condition = array(
                "columnName" => $key,
                "operator"   => "=",
                "value"      => $value
            );
        }

        // para o CTRL+F funcionar
        for($i = 0; $i < count($conditions); $i++) {
            if(strpos($dataSourceFilter[$i]["columnName"], '|') != false) {
                $dataSourceFilter[$i]["operator"] = "MAPPED_LIKE_ALL";
            }
        }

        $newRequest = new DTO\Request\Filter (
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        parent::find($newRequest, $response);
        return $result;
    }
    
    public function findExportacao(DTO\Request\Row $request, DTO\Response $response) {
        $result = [];
        $dataSourceName = $this->dataSourceName = 'vnd09500R_relSaldoAtualporConsumidor';

        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParamsSaldo($conditions);
 
        if(isset($conditions['DTEXTRATOINI']) && !empty($conditions['DTEXTRATOINI']) &&
           isset($conditions['DTEXTRATOFIN']) && !empty($conditions['DTEXTRATOFIN'])) {
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"   => "=",
                    "value"      => $value
                );
            }

            // para o CTRL+F funcionar
            for($i = 0; $i < count($conditions); $i++) {
                if(strpos($dataSourceFilter[$i]["columnName"], '|') != false) {
                    $dataSourceFilter[$i]["operator"] = "MAPPED_LIKE_ALL";
                }
            }

            $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $dataSourceName,
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );

            parent::find($newRequest, $response);
        }

        return $result;
    }

    public function buildParamsSaldo($conditions) {

        if(!Functions::arrayKeyExists('CDCONSUMIDOR', $conditions)) {
            $conditions['CDCONSUMIDOR'] = '';
            $conditions['TCDCONSUMIDOR'] = 'T';
        } else {
            $conditions['CDCONSUMIDOR'] = '_'.implode('_', $conditions['CDCONSUMIDOR']).'_';
            $conditions['TCDCONSUMIDOR'] = '';
        }

        if(!Functions::arrayKeyExists('CDTIPOCONS', $conditions)) {
            $conditions['CDTIPOCONS'] = '';
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = '_'.implode('_', $conditions['CDTIPOCONS']).'_';
            $conditions['TCDTIPOCONS'] = '';
        }

        if(!Functions::arrayKeyExists('CDFAMILISALD', $conditions)) {
            $conditions['CDFAMILISALD'] = '';
            $conditions['TCDFAMILISALD'] = 'T';
        } else {
            $conditions['CDFAMILISALD'] = '_'.implode('_', $conditions['CDFAMILISALD']).'_';
            $conditions['TCDFAMILISALD'] = '';
        }

        if(Functions::arrayKeyExists('CDFILIAL', $conditions)) {
            unset($conditions['CDFILIAL']);
        }

        if(Functions::arrayKeyExists('NRORG', $conditions)) {
            unset($conditions['NRORG']);
        }

        if(Functions::arrayKeyExists('NMRAZSOCCLIE', $conditions)) {
            unset($conditions['NMRAZSOCCLIE']);
        }

        return $conditions;
    }
}
